import { AstroError } from "../core/errors/index.js";
import { MissingLocale } from "../core/errors/errors-data.js";
import { shouldAppendForwardSlash } from "../core/build/util.js";
import { appendForwardSlash, joinPaths } from "@astrojs/internal-helpers/path";
function getLocaleRelativeUrl({
  locale,
  base,
  locales,
  trailingSlash,
  format,
  path,
  prependWith,
  normalizeLocale = false
}) {
  if (!locales.includes(locale)) {
    throw new AstroError({
      ...MissingLocale,
      message: MissingLocale.message(locale, locales)
    });
  }
  const normalizedLocale = normalizeTheLocale(locale, normalizeLocale);
  if (shouldAppendForwardSlash(trailingSlash, format)) {
    return appendForwardSlash(joinPaths(base, prependWith, normalizedLocale, path));
  } else {
    return joinPaths(base, prependWith, normalizedLocale, path);
  }
}
function getLocaleAbsoluteUrl({ site, ...rest }) {
  const locale = getLocaleRelativeUrl(rest);
  if (site) {
    return joinPaths(site, locale);
  } else {
    return locale;
  }
}
function getLocaleRelativeUrlList({
  base,
  locales,
  trailingSlash,
  format,
  path,
  prependWith,
  normalizeLocale = false
}) {
  return locales.map((locale) => {
    const normalizedLocale = normalizeTheLocale(locale, normalizeLocale);
    if (shouldAppendForwardSlash(trailingSlash, format)) {
      return appendForwardSlash(joinPaths(base, prependWith, normalizedLocale, path));
    } else {
      return joinPaths(base, prependWith, normalizedLocale, path);
    }
  });
}
function getLocaleAbsoluteUrlList({ site, ...rest }) {
  const locales = getLocaleRelativeUrlList(rest);
  return locales.map((locale) => {
    if (site) {
      return joinPaths(site, locale);
    } else {
      return locale;
    }
  });
}
function normalizeTheLocale(locale, shouldNormalize) {
  if (!shouldNormalize) {
    return locale;
  }
  return locale.replaceAll("_", "-").toLowerCase();
}
export {
  getLocaleAbsoluteUrl,
  getLocaleAbsoluteUrlList,
  getLocaleRelativeUrl,
  getLocaleRelativeUrlList
};
